########################################################################
########################################################################
##Midwest Ecotraps Analysis: distribution shift analysis 
##Copyright 2020 Skylar Hopkins

#This script calculates how the average estimated November roosting temperature 
#changed from pre-invasion to invasion to post-invasion and makes a figure illustrating 
#these distribution shifts across invasion periods and how they correspond to the temperature 
#distributions of banded bats that were and were not recaptured. 

#Permission is hereby granted, free of charge, to any person obtaining a copy of this 
#software and associated documentation files (the "Software"), to deal in the Software 
#without restriction, including without limitation the rights to use, copy, modify, merge, 
#publish, distribute, sublicense, and/or sell copies of the Software, and to permit 
#persons to whom the Software is furnished to do so, subject to the following conditions:

#The above copyright notice and this permission notice shall be included in all 
#copies or substantial portions of the Software.

#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
#INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
#PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR 
#ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
#ARISING FROM, OUT OF OR IN #CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

########################################################################
########################################################################

#clear workspace
rm(list=ls())

########################################################################
######################load important packages##########################
########################################################################
library(plotrix)
library(ggplot2)
library(reshape2)
library(tidyverse)
library(viridis)
library(naniar)
library(ciTools)
library(dplyr)
library(ggridges)
library(readxl)
library(diptest)
library(cowplot)
select <- dplyr::select

###############################################################################################
#######Part 1: Load the individual temp and swab data and the section-level counts############
##############################################################################################

#Cleaned MYLU swab data
dm <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/DistributionShiftAnalysis_CleanedMYLUSwabData.csv")
#Cleaned MYLU Band data
MYLUBands <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/Cleaned MYLU Band Data for Ecotraps Analysis.csv")
#Cleaned Inf MYLU Band/Recap data
MYLUBands_RecapAnalysis <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/Cleaned Inf MYLU Band Recap Data for Ecotraps Analysis.csv")
#Cleaned count data
CountData <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/DistributionShiftAnalysis_CleanedCountData.csv")

#####################################################################################
###Part 2: Calculate mean and sd of swabbed bat temps by section##########################
#####################################################################################
##Make a count vs swab database
SwabsBySection <- dm %>%
  group_by(y, ysw, site, section2, wyear, pdate) %>%
  summarise(numswabbed=n(), numswabbed2=sum(is.na(temp)), meantemp=mean(temp, na.rm=T), sdtemp=sd(temp, na.rm=T), meanysw=mean(ysw, na.rm=T))
names(SwabsBySection)[names(SwabsBySection)=="meanysw"]<-"ysw"

SwabsBySection$SiteSectionYear<-paste(SwabsBySection$site, SwabsBySection$section2, SwabsBySection$wyear, sep=".")
CountData$SiteSectionYear<-paste(CountData$site, CountData$section2, CountData$wyear, sep=".")
CountData$numswabbed<-SwabsBySection$numswabbed[match(CountData$SiteSectionYear, SwabsBySection$SiteSectionYear)]
CountData$meantemp<-SwabsBySection$meantemp[match(CountData$SiteSectionYear, SwabsBySection$SiteSectionYear)]
CountData$sdtemp<-SwabsBySection$sdtemp[match(CountData$SiteSectionYear, SwabsBySection$SiteSectionYear)]
CountData$numswabbed2<-SwabsBySection$numswabbed2[match(CountData$SiteSectionYear, SwabsBySection$SiteSectionYear)]

#FIX MISSING THINGS
#BEA.E.2014, BEA.E.2016, BEA.E.2017
#bats were never swabbed in section E, but only a few bats were counted there, so just remove
REMOVE<-which(CountData$site=="BEA" & CountData$section2=="E")
CountData<-CountData[-REMOVE,]

#ELRL - Nov 14 - no temps from C. Average C temps across years
ggplot(data=dm[dm$site=="ELRL",], aes(x=y, y=temp, col=section2))+
  geom_point()
CountData$meantemp[CountData$site=="ELRL" & CountData$y==2014 & CountData$section2=="C"]<-mean(dm$temp[dm$site=="ELRL" & dm$section2=="C"], na.rm=T)
CountData$sdtemp[CountData$site=="ELRL" & CountData$y==2014 & CountData$section2=="C"]<-sd(dm$temp[dm$site=="ELRL" & dm$section2=="C"], na.rm=T)
#ELRL.B.2013 - only swabbed one bat, so SD is NA. Use SD across all years
CountData$sdtemp[CountData$site=="ELRL" & CountData$wyear==2013 & CountData$section2=="B"]<-sd(dm$temp[dm$site=="ELRL" & dm$section2=="B"], na.rm=T)
#Section D didn't have swab data after 2012, but only a few bats found there, so just remove D in 2012
REMOVE<-which(CountData$site=="ELRL" & CountData$section2=="D")
CountData<-CountData[-REMOVE,]
#ELRL.B.2015 - only one swabbed bat had a temp. Get SD from all years
dm$temp[dm$site=="ELRL" & dm$section2=="B" & dm$wyear==2015]
CountData$sdtemp[CountData$site=="ELRL" & CountData$wyear==2015 & CountData$section2=="B"]<-sd(dm$temp[dm$site=="ELRL" & dm$section2=="B"], na.rm=T)
#ELRL.B.2016 only one swabbed bat had a temp. Get SD from all years
CountData$sdtemp[CountData$site=="ELRL" & CountData$wyear==2016 & CountData$section2=="B"]<-sd(dm$temp[dm$site=="ELRL" & dm$section2=="B"], na.rm=T)

#GLE.ALL.2020 - only one swabbed bat so no SD. That's OK, because just one counted

#No bats swabbed in 2013 Section D of HORR, so mean over all years in that section
#Since that was the big section, do the same for 2016-2018
ggplot(data=dm[dm$site=="HORR",], aes(x=y, y=temp, col=section2))+
  geom_point()
CountData$meantemp[CountData$site=="HORR" & CountData$y %in% c(2013, 2016, 2017, 2018) & CountData$section2=="D"]<-mean(dm$temp[dm$site=="HORR" & dm$section2=="D"], na.rm=T)
CountData$sdtemp[CountData$site=="HORR" & CountData$y %in% c(2013, 2016, 2017, 2018) & CountData$section2=="D"]<-sd(dm$temp[dm$site=="HORR" & dm$section2=="D"], na.rm=T)
#HORR.A.2013 - only one swabbed bat so no SD. That's OK, because just one counted
#HORR.A.2017 and HORR.B.2017 - only one swabbed bat so no SD. That's OK, because just one counted
#HORR.C.2017 - only one swabbed bat so no SD. Use SD for all years
CountData$sdtemp[CountData$site=="HORR" & CountData$wyear==2017 & CountData$section2=="C"]<-sd(dm$temp[dm$site=="HORR" & dm$section2=="C"], na.rm=T)
#HORR.A.2018 and HORR.B.2018 - only one swabbed bat so no SD. That's OK, because just one counted
#HORR.B.2019 and HORR.C.2019 - only one swabbed bat so no SD. That's OK, because just one counted
#HORR.C.2020 - one counted bat not swabbed. Average of all years
CountData$meantemp[CountData$site=="HORR" & CountData$wyear %in% c(2020) & CountData$section2=="C"]<-mean(dm$temp[dm$site=="HORR" & dm$section2=="C"], na.rm=T)
CountData$sdtemp[CountData$site=="HORR" & CountData$wyear %in% c(2020) & CountData$section2=="C"]<-sd(dm$temp[dm$site=="HORR" & dm$section2=="C"], na.rm=T)
#Section D had swabbed bats but no temps in 2020. Average of all years
dm[dm$site=="HORR" & dm$wyear==2020,]
CountData$meantemp[CountData$site=="HORR" & CountData$wyear %in% c(2020) & CountData$section2=="D"]<-mean(dm$temp[dm$site=="HORR" & dm$section2=="D"], na.rm=T)
CountData$sdtemp[CountData$site=="HORR" & CountData$wyear %in% c(2020) & CountData$section2=="D"]<-sd(dm$temp[dm$site=="HORR" & dm$section2=="D"], na.rm=T)

#No 2015 HR swabs for MAR. Ave across years - ONLY IF DONT LUMP AS ALL
ggplot(data=dm[dm$site=="MAR",], aes(x=y, y=temp, col=section2))+
  geom_point()
CountData$meantemp[CountData$site=="MAR" & CountData$y==2015 & CountData$section2=="HR"]<-mean(dm$temp[dm$site=="MAR" & dm$section2=="HR"], na.rm=T)
CountData$sdtemp[CountData$site=="MAR" & CountData$y==2015 & CountData$section2=="HR"]<-sd(dm$temp[dm$site=="MAR" & dm$section2=="HR"], na.rm=T)
#No 2014 SEL swabs for MAR - ave across years
CountData$meantemp[CountData$site=="MAR" & CountData$y==2014 & CountData$section2=="SEL"]<-mean(dm$temp[dm$site=="MAR" & dm$section2=="SEL"], na.rm=T)
CountData$sdtemp[CountData$site=="MAR" & CountData$y==2014 & CountData$section2=="SEL"]<-sd(dm$temp[dm$site=="MAR" & dm$section2=="SEL"], na.rm=T)
#MAR.WL.2017 and MAR.WL.2018 - no SD. Average over years
CountData$sdtemp[CountData$site=="MAR" & is.na(CountData$sdtemp) & CountData$section2=="WL"]<-sd(dm$temp[dm$site=="MAR" & dm$section2=="WL"], na.rm=T)

#No swab data for pre-2014 MAS even though we have counts, so take out pre-2014 counts
ggplot(data=dm[dm$site=="MAS",], aes(x=y, y=temp, col=section2))+
  geom_point()
REMOVE<-which(CountData$y<2014 & CountData$site=="MAS")
CountData<-CountData[-REMOVE,]

#ST. 2015 all bats handled but no temps - average across C
ggplot(data=dm[dm$site=="ST.",], aes(x=y, y=temp, col=section2))+
  geom_point()
CountData$meantemp[CountData$site=="ST." & CountData$y==2015 & CountData$section2=="ALL"]<-mean(dm$temp[dm$site=="ST." & dm$section2=="C"], na.rm=T)
CountData$sdtemp[CountData$site=="ST." & CountData$y==2015 & CountData$section2=="ALL"]<-sd(dm$temp[dm$site=="ST." & dm$section2=="C"], na.rm=T)
#No bats ever swabbed with temps from A, so just remove all section A
dm[dm$site=="ST." & dm$section2=="A",]
REMOVE<-which(CountData$section2=="A" & CountData$site=="ST.")
CountData<-CountData[-REMOVE,]

#JOHT.E.2014, JOHT.E.2016 - only swabbed one bat so no SD, but OK because only one counted

##################################################################################################
##########Fill in estimated temperature data and plot############################
##################################################################################################

CountData<-CountData[CountData$clustersize>0,]
CountData <- CountData %>%
  arrange(site, section2, wyear)
#View(CountData)

#Make one row for every bat counted BUT NOT SWABBED that has a temp
CountData$numswabbed[is.na(CountData$numswabbed)]<-0
CountData$numswabbed2[is.na(CountData$numswabbed2)]<-0
CountData$freq<-CountData$clustersize-CountData$numswabbed+CountData$numswabbed2 #add back NAs for temp
#View(CountData[CountData$freq<0,])
CountData<-CountData[CountData$freq>=0,]

#Estimate temps for counts w/ no swab
MissingTemps <- CountData %>%
  uncount(weights=freq)
MissingTemps$temp<-rnorm(n = length(MissingTemps$meantemp), mean = MissingTemps$meantemp, sd=MissingTemps$sdtemp)
MissingTemps$KnownYN<-0
MissingTemps$gdL<-NA
dim(MissingTemps)

#Merge actual temps and estimates into one data frame
KnownTemps<-subset(dm, select=c(site, section2, wyear, pdate, temp, ysw, gdL))
KnownTemps$KnownYN<-1
dim(KnownTemps)

names(MissingTemps)
names(KnownTemps)
Temps<-bind_rows(KnownTemps, MissingTemps[,c(4:7, 14, 3, 16, 15)])
table(Temps$site)
table(Temps$site, Temps$ysw)

#Make invasion bins
Temps$YSWBins<-"Pre-Invasion"; Temps$YSWBins[Temps$ysw==1]<-"Invasion"; Temps$YSWBins[Temps$ysw==2]<-"Invasion"; Temps$YSWBins[Temps$ysw>2]<-"Post-Invasion"
Temps$YSWBins<-factor(Temps$YSWBins, levels = c("Pre-Invasion", "Invasion", "Post-Invasion"))

table(Temps$site, Temps$YSWBins) #3 sites extirpated
table(Temps$site, Temps$ysw) 

Summary<-Temps %>%
  group_by(site, YSWBins) %>%
  summarise(meantemp=mean(temp, na.rm=T), count=n())

graph<-ggplot(data=Summary, aes(y=meantemp, x=YSWBins, col=as.factor(site))) +
  geom_point(aes(size=log10(count))) +
  geom_line(aes(y=meantemp, x=as.numeric(YSWBins), group=site)) +
  theme_bw()+
  ylab("Mean temp") +
  xlab("Period") +
  #labs(fill = "RecapYN") + 
  theme(panel.grid = element_blank(),axis.title=element_text(size=10),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="right",legend.text = element_text(size=10,face="italic"),strip.text = element_text(size=10,face="italic"))
graph

#models
test<-lm(temp~YSWBins, data=Temps); summary(test)
test<-lm(temp~YSWBins, data=Temps[Temps$KnownYN==1,]); summary(test) #same qualitative trend

min(Temps$temp[Temps$KnownYN==1 & Temps$YSWBins=="Pre-Invasion"], na.rm=T)
max(Temps$temp[Temps$KnownYN==1 & Temps$YSWBins=="Pre-Invasion"], na.rm=T)
mean(Temps$temp[Temps$KnownYN==1 & Temps$YSWBins=="Pre-Invasion"], na.rm=T)
mean(Temps$temp[Temps$YSWBins=="Pre-Invasion"], na.rm=T)

########################################################################
########################################################################
########################################################################
######################Part 3: PLOT#####################################
########################################################################
########################################################################
########################################################################

#To do this, we need to plot the same recap data in invasion and postinvasion - here's some re-organizing to do that
names(MYLUBands_RecapAnalysis)
MYLUBands_RecapAnalysis$YSWBins<-"Pre-Invasion"; MYLUBands_RecapAnalysis$YSWBins[MYLUBands_RecapAnalysis$ysw.x>=0]<-"Invasion"
MYLUBands_RecapAnalysis$YSWBins<-factor(MYLUBands_RecapAnalysis$YSWBins, levels = c("Pre-Invasion", "Invasion"))
which(is.na(MYLUBands_RecapAnalysis$YSWBins))

MYLUBands_RecapAnalysis2<-MYLUBands_RecapAnalysis
MYLUBands_RecapAnalysis2$YSWBins<-"Pre-Invasion"; MYLUBands_RecapAnalysis2$YSWBins[MYLUBands_RecapAnalysis2$ysw.x>=0]<-"Post-Invasion"
MYLUBands_RecapAnalysis2$YSWBins<-factor(MYLUBands_RecapAnalysis2$YSWBins, levels = c("Pre-Invasion", "Post-Invasion"))

table(Temps$YSWBins)
table(Temps$YSWBins[Temps$KnownYN==1])
table(Temps$site)

#plot
levels(Temps$YSWBins)
levels(Temps$YSWBins) <- c("Pre-Invasion", "Invasion (40% recaptured)", "Post-Invasion (53% recaptured)")
levels(MYLUBands_RecapAnalysis$YSWBins)
levels(MYLUBands_RecapAnalysis$YSWBins)<-c("Pre-Invasion", "Invasion (40% recaptured)")
levels(MYLUBands_RecapAnalysis2$YSWBins)
levels(MYLUBands_RecapAnalysis2$YSWBins)<-c("Pre-Invasion", "Post-Invasion (53% recaptured)")

bw<-1
density<-ggplot(data=Temps, aes(x=temp)) +
  geom_density(linetype=0, col="gray75", bw=bw, data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$YSWBins!="Pre-Invasion (20% recaptured)" & MYLUBands_RecapAnalysis$YSWBins!="Post-Invasion (53% recaptured)",], aes(x=earlytemp, group=EverRecapturedYN.x, fill=as.factor(EverRecapturedYN.x)), alpha=0.5) +
  geom_density(linetype=0, col="gray75", bw=bw, data=MYLUBands_RecapAnalysis2[MYLUBands_RecapAnalysis2$YSWBins!="Pre-Invasion (20% recaptured)" & MYLUBands_RecapAnalysis2$YSWBins!="Invasion (41% recaptured)",], aes(x=earlytemp, group=EverRecapturedYN.x, fill=as.factor(EverRecapturedYN.x)), alpha=0.5) +
  geom_density(bw=bw, alpha=0.6, fill="black") +
  facet_wrap(~YSWBins, nrow=3) +
  theme_bw()+
  ylab("Density") +
  xlab(expression(November~roosting~temperature~(degree~C))) +
  #labs(fill = "RecapYN") + 
  theme(panel.grid = element_blank(),axis.title=element_text(size=10),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="none",legend.text = element_text(size=10),strip.text = element_text(size=10))
density

hist<-ggplot(data=Temps, aes(x=temp)) +
  geom_histogram(binwidth = 1, alpha=0.6, fill="black") +
  #facet_wrap(~YSWBins, nrow=3, scales="free_y") +
  facet_wrap(~YSWBins, nrow=3) +
  theme_bw()+
  ylab("Frequency") +
  xlab(expression(November~roosting~temperature~(degree~C))) +
  #labs(fill = "RecapYN") + 
  theme(panel.grid = element_blank(),axis.title=element_text(size=10),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="none",legend.text = element_text(size=10),strip.text = element_text(size=10))
hist

plot_grid(density, hist, nrow=1, labels=c("A", "B"))

##
#Combine histogram and density plots
##
table(Temps$wyear)
table(Temps$YSWBins)

comb<-ggplot(data=Temps, aes(x=temp)) +
  geom_density(linetype=0, col="gray75", bw=bw, data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$YSWBins!="Pre-Invasion (20% recaptured)" & MYLUBands_RecapAnalysis$YSWBins!="Post-Invasion (53% recaptured)",], aes(x=earlytemp, group=EverRecapturedYN.x, fill=as.factor(EverRecapturedYN.x)), alpha=0.5) +
  geom_density(linetype=0, col="gray75", bw=bw, data=MYLUBands_RecapAnalysis2[MYLUBands_RecapAnalysis2$YSWBins!="Pre-Invasion (20% recaptured)" & MYLUBands_RecapAnalysis2$YSWBins!="Invasion (41% recaptured)",], aes(x=earlytemp, group=EverRecapturedYN.x, fill=as.factor(EverRecapturedYN.x)), alpha=0.5) +
  #geom_density(bw=1, alpha=0.3, fill="black", aes(y=..density..)) +
  geom_density(linetype=0, bw=1, alpha=0.4, fill="black", aes(y=..density..)) +
  geom_histogram(data=Temps, binwidth = 1, alpha=1, fill="black", aes(y=..count../10000)) +
  scale_y_continuous(limits = c(0, 0.3), sec.axis = sec_axis(trans = ~.*10000, name = "Total population size")) +
  facet_wrap(~YSWBins, nrow=3) +
  scale_x_continuous(limits = c(3,13)) +
  theme_bw()+
  ylab("Density") +
  xlab(expression(November~roosting~temperature~(degree~C))) +
  #labs(fill = "RecapYN") + 
  theme(panel.grid = element_blank(),axis.title=element_text(size=10),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="none",legend.text = element_text(size=10),strip.text = element_text(size=10))
comb
ggsave(file=paste("Fig5.pdf", sep=""),width=6,height=5,units="in",limitsize=FALSE)

##
##
#site-level pre-invasion: supplementary figure
##
##
bw<-0.5
graph<-ggplot(data=Temps[!Temps$YSWBins%in% c("Invasion (40% recaptured)", "Post-Invasion (53% recaptured)"),], aes(x=temp)) +
  geom_density(bw=bw, alpha=0.6, aes(group=site, fill=site)) +
  theme_bw()+
  ylab("Frequency") +
  xlab(expression(November~roosting~temperature~(degree~C))) +
  #labs(fill = "RecapYN") + 
  theme(panel.grid = element_blank(),axis.title=element_text(size=10),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="none",legend.text = element_text(size=10,face="italic"),strip.text = element_text(size=10,face="italic"))
graph