########################################################################
########################################################################
##Midwest Ecotraps Analysis: bat recaptures versus temp 
##Copyright 2020 Skylar Hopkins

#This script runs the logistic regression for the recapture analysis, 
#performs 5-fold cross-validation on 1000 random divisions of our dataset, 
#and then calculates the average Area Under the Curve (AUC) for the resulting 
#1000 Receiver Operating Characteristic (ROC) curves. This script also makes 
#the logistic regression and partial residuals figures for the paper. 

#Permission is hereby granted, free of charge, to any person obtaining a copy of this 
#software and associated documentation files (the "Software"), to deal in the Software 
#without restriction, including without limitation the rights to use, copy, modify, merge, 
#publish, distribute, sublicense, and/or sell copies of the Software, and to permit 
#persons to whom the Software is furnished to do so, subject to the following conditions:

#The above copyright notice and this permission notice shall be included in all 
#copies or substantial portions of the Software.

#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
#INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
#PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR 
#ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
#ARISING FROM, OUT OF OR IN #CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

########################################################################
########################################################################

#clear workspace
rm(list=ls())

########################################################################
#################load packages and data##########################
########################################################################
library(readr)
library(tidyverse)
library(ggplot2)
library(dplyr)
library(MuMIn)
library(lme4)
library(binom)
library(MASS)
library(viridis)
library(naniar)
library(ciTools)
library(nlme)
library(cowplot)

#Cleaned MYLU swab data
dm <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/Cleaned MYLU Swab Data for Ecotraps Analysis.csv")
#Cleaned MYLU Band data
MYLUBands <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/Cleaned MYLU Band Data for Ecotraps Analysis.csv")
#Cleaned Inf MYLU Band/Recap data
MYLUBands_RecapAnalysis <- read.csv("~/Dropbox/Hopkins_VT_postdoc/HopkinsGit/Midwest EcoTraps Paper/Final Scripts for Paper/Cleaned Inf MYLU Band Recap Data for Ecotraps Analysis.csv")

#Some quick data exploration
table(MYLUBands_RecapAnalysis$RecapturedSameYearYN.x)
table(MYLUBands_RecapAnalysis$EverRecapturedYN.x)
table(MYLUBands_RecapAnalysis$RecapturedSameYearYN.x, MYLUBands_RecapAnalysis$EverRecapturedYN.x)
hist(MYLUBands_RecapAnalysis$logearlyloads)

##############################################################################################################
##Does recapture probability IN ONE YEAR depend on load and temp? Not the model that goes into paper########################
##############################################################################################################
#7 bats were not re-sighted in spring and then re-sighted in a later year (see tables above), 
#so this underestimates survival slightly
mod3 = glmer(RecapturedSameYearYN.x~earlytemp+logearlyloads + (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis, control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod3)
mod4 = glmer(RecapturedSameYearYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis, control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod4)
AIC(mod3,mod4) #mod4 is a bit most parsimonious (interaction term)

#Generate prediction lines
nd <- expand.grid(logearlyloads=seq(-4,0,0.1),earlytemp=seq(0, 14, 0.05))
nd$phat <- predict(mod4, nd, type="response", re.form=~0)
#nd$phat <- predict(mod4, nd, type="response", re.form=~0)

#Plot logistic regression 
c=ggplot(MYLUBands_RecapAnalysis, aes(x=earlytemp, y=RecapturedSameYearYN.x, color=logearlyloads)) +
  geom_jitter(width = NULL, height = 0.03, size=5, alpha=0.7, aes(color=logearlyloads)) +
  geom_line(data=subset(nd,logearlyloads==-4),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-3),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-2),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-1),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  ylab("Probability of Recapture in Year")+
  xlab(expression("Early roosting temperature (degrees C)"))+
  scale_colour_viridis(option="inferno")+
  scale_x_continuous(limits =c(4.5, 12), breaks=seq(6,12,2)) +
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position="right",legend.text = element_text(size=20,face="italic"),strip.text = element_text(size=25,face="italic")) +
  labs(color="log10(load)")
c

###############################################################################################################
#Ever recaptured - does your recapture probability depend on load and temp? Model that goes in paper
##############################################################################################################
mod3 = glmer(EverRecapturedYN.x~earlytemp+logearlyloads + (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis, control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod3)
mod4 = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis, control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod4)
AIC(mod3,mod4) #mod4 is most parsimonious (interaction term)
MuMIn::r.squaredGLMM(mod4) 

#Residual plots for mod4- OK
par(mar=c(4,4,1,1))
plot(resid(mod4, type="pearson")); abline(h=2); abline(h=-2)
plot(resid(mod4, type="pearson")~MYLUBands_RecapAnalysis$earlytemp[!is.na(MYLUBands_RecapAnalysis$earlytemp)]); abline(h=2); abline(h=-2)
(length(which(resid(mod4, type="pearson")>2)) + length(which(resid(mod4, type="pearson")< -2)))/length(resid(mod4, type="pearson")) #OK

###############################################################################################################
##########################Final figure for the recap analysis###########################################
###############################################################################################################
BinnedRecaps<-MYLUBands_RecapAnalysis %>%
  filter(!is.na(earlytemp)) %>%
  group_by(TempBin=round(earlytemp, 0)) %>%
  summarise(Count=n(), EverRecaptured=sum(EverRecapturedYN.x)) %>%
  mutate(PercentRecaptured=EverRecaptured/Count)

#Generate prediction lines
nd <- expand.grid(logearlyloads=seq(-4,0,0.1),earlytemp=seq(0, 14, 0.05))
nd$phat <- predict(mod4, nd, type="response", re.form=~0)

c=ggplot(MYLUBands_RecapAnalysis, aes(x=earlytemp, y=EverRecapturedYN.x)) +
  geom_jitter(size=2, width = NULL, height = 0.01, alpha=0.6, aes(color=logearlyloads)) +
  geom_line(data=subset(nd,logearlyloads==-4),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-3),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-2),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  geom_line(data=subset(nd,logearlyloads==-1.5),aes(x=earlytemp,y=phat,color=logearlyloads),size=2)+#linetype="dashed"
  #could size=Count, but we took out
  geom_point(data=BinnedRecaps, size=5, aes(x=TempBin, y=PercentRecaptured), col="black", pch=16, alpha=0.9) +
  ylab("Bat recapture probability")+
  xlab(expression(Early~roosting~temperature~(degree~C)))+
  scale_colour_viridis(breaks=seq(-4, 0, 1), begin=0.3, end=1, option="inferno")+
  scale_x_continuous(limits =c(4.5, 12), breaks=seq(6,12,2)) +
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=12), axis.line=element_line(),
        legend.position = c(0.88, 0.67), legend.text = element_text(size=10)) +
  labs(color=expression(italic(Pd)~load~(log[10])))
c
#ggsave(file=paste(getwd(), "/Midwest EcoTraps Paper/Fig2_LogisticRegressionFigure.pdf", sep = ""),width=6.5,height=5,units="in",limitsize=FALSE)
ggsave(file=paste("Fig3.pdf", sep = ""),width=6.5,height=5,units="in",limitsize=FALSE)

####################################################################################################
############Partial regression to account for ysw in recap probabilities########################
###############################################################################################
#We can't add YSW to the recap model because YSW and temp are correlated. Instead, we use a partial
#regression to see if there's any effect of YSW after accounting for temp (there isn't)

#What proportion of bats survived in inv vs. post-invasion?
MYLUBands_RecapAnalysis %>%
  group_by(YSWBins) %>%
  summarise(EverRecapturedYN=sum(EverRecapturedYN.x, na.rm=T), TotalBats=n()) %>%
  mutate(PercentRecaptured=(EverRecapturedYN/TotalBats)*100)

#What proportion of bats survived each ysw?
YSWRecaps<-MYLUBands_RecapAnalysis %>%
  group_by(ysw.x) %>%
  summarise(EverRecapturedYN=sum(EverRecapturedYN.x, na.rm=T), TotalBats=n(), MeanTemp=mean(earlytemp[season.x=="hiber_earl"], na.rm=T), SDTemp=sd(earlytemp[season.x=="hiber_earl"], na.rm=T)) %>%
  mutate(PercentRecaptured=(EverRecapturedYN/TotalBats)*100, lowMean=(MeanTemp-1.96*SDTemp/sqrt(TotalBats)), highMean=(MeanTemp+1.96*SDTemp/sqrt(TotalBats)))

#Add binomial confidence intervals
for(i in 1:length(YSWRecaps$EverRecapturedYN)) {
  YSWRecaps$Low[i]<-as.numeric(binom.confint(YSWRecaps$EverRecapturedYN[i], YSWRecaps$TotalBats[i], conf.level = 0.95, methods = "wilson")[5])*100
  YSWRecaps$High[i]<-as.numeric(binom.confint(YSWRecaps$EverRecapturedYN[i], YSWRecaps$TotalBats[i], conf.level = 0.95, methods = "wilson")[6])*100
}

#Run the recap vs. ysw model and plot
mod5 = glmer(EverRecapturedYN.x~ysw.x+ (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis, control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod5)
nd <- expand.grid(ysw.x=seq(0,4.5,0.4))
nd$phat <- predict(mod5, nd, type="response", re.form=~0)

a=ggplot(YSWRecaps, aes(x=ysw.x)) +
  geom_line(data=nd,aes(x=ysw.x,y=phat),size=2,linetype="dashed")+
  geom_point(aes(size=TotalBats, y=(PercentRecaptured/100)), pch=16, col="black") +
  geom_linerange(aes(ymin = Low/100, ymax = High/100), col="black") +
  geom_jitter(data=MYLUBands_RecapAnalysis, alpha=0.9, size=1, pch=16, aes(y=EverRecapturedYN.x, col=earlytemp), height=0.025, width=0.15) +
  ylab("Proportion recaptured")+
  xlab("Years since fungus was first detected")+
  scale_colour_viridis(option="viridis")+
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=12), axis.line=element_line(),
        legend.position = c(0.25, 0.75), legend.text = element_text(size=10)) +
  guides(color = FALSE) +
  labs(size="Num. banded bats")
a

#Run the recap vs. temp model and plot
mod = lm(earlytemp~ysw.x, data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$ysw.x>0,]); summary(mod)
nd <- expand.grid(ysw.x=seq(0,4.5,0.4))
nd$phat <- predict(mod, nd, type="response", re.form=~0)

b=ggplot(YSWRecaps, aes(x=ysw.x)) +
  geom_line(data=nd,aes(x=ysw.x,y=phat),size=2,linetype="dashed")+
  geom_jitter(data=MYLUBands_RecapAnalysis, size=1, pch=16, aes(y=earlytemp, col=earlytemp), width=0.15, alpha=0.9) +
  geom_linerange(aes(ymin = lowMean, ymax = highMean), col="black") +
  geom_point(aes(size=TotalBats, y=MeanTemp), pch=16, col="black") +
  ylab("Early roosting temperature")+
  xlab("Years since fungus was first detected")+
  scale_colour_viridis(option="viridis")+
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=12), axis.line=element_line(),
        legend.position = c(0.25, 0.2), legend.text = element_text(size=10)) +
  guides(size = FALSE) +
  labs(col="Temp. (°C)")
b

#Partial regression analysis and plot
#First we get the resids from our recap vs temp*load model
mod4 = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(link="logit"),data=MYLUBands_RecapAnalysis[!is.na(MYLUBands_RecapAnalysis$earlytemp),], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))); summary(mod4)
length(residuals(mod4, type="pearson"))
length(MYLUBands_RecapAnalysis$ysw.x[!is.na(MYLUBands_RecapAnalysis$earlytemp)])
Data<-as.data.frame(cbind(Resids=residuals(mod4, type="pearson"), YSW=MYLUBands_RecapAnalysis$ysw.x[!is.na(MYLUBands_RecapAnalysis$earlytemp)], Temps=MYLUBands_RecapAnalysis$earlytemp[!is.na(MYLUBands_RecapAnalysis$earlytemp)]))
head(Data)
ggplot(Data, aes(YSW, Resids)) +
  geom_point() +
  geom_smooth() +
  ylab("Pearson residuals")
test<-lm(Resids~YSW, data=Data); summary(test)

#Now we get the resids from a YSW vs temp*load model
plot(Data$YSW~Data$Temps)
test = glm(ysw.x~earlytemp*logearlyloads, data=MYLUBands_RecapAnalysis[!is.na(MYLUBands_RecapAnalysis$earlytemp),], family="poisson"); summary(test)
#test = lmer(ysw.x~earlytemp*logearlyloads + (1|site.x), data=MYLUBands_RecapAnalysis[!is.na(MYLUBands_RecapAnalysis$earlytemp),]); summary(test)
plot(residuals(test, type="pearson")~MYLUBands_RecapAnalysis$earlytemp[!is.na(MYLUBands_RecapAnalysis$earlytemp)])
plot(residuals(test, type="pearson")~MYLUBands_RecapAnalysis$logearlyloads[!is.na(MYLUBands_RecapAnalysis$earlytemp)])
Data$YSWResid<-residuals(test, type="pearson")

c<-ggplot(Data, aes(YSWResid, Resids, col=Temps)) +
  geom_point(pch=16, alpha=0.9) +
  #geom_smooth() +
  theme_bw()+
  ylab("Recaptures | Early temperatures * loads") +
  xlab("YSW | Early temperatures * loads") +
  scale_colour_viridis(option="viridis")+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=12), axis.line=element_line(),
        legend.position = "none", legend.text = element_text(size=10))
c

#Is there any left over relationship between recaps and YSW? No.
test<-lm(Resids~YSWResid, data=Data); summary(test)

##Compile the partial regression plots into one figure, now Fig 3
plot_grid(a, b, c, labels = c('A', 'B', 'C'), nrow=1)
ggsave(file=paste("PartialReg.pdf", sep=""),width=13,height=5,units="in",limitsize=FALSE)
ggsave(file=paste(getwd(), "/Midwest EcoTraps Paper/PartialReg.png", sep=""),width=13,height=5,units="in",limitsize=FALSE)

#####################################################################################
########Cross Validation for Recap Analysis and ROC plot################################
###################################################################################
#We initially used repeated 5-fold CV, which gives the same result, but that old code is in the 
#"Midwest Early Temp and Loads vs. Load Change" script. Here we use an AUC analysis

#Make an ROC curve based on each datapoint ending up in a test set just one time
#5-fold CV just once
L<-length(MYLUBands_RecapAnalysis$swab_id.x)
Folds<-c(rep(1, (L-4*trunc(L/4))), rep(2, trunc(L/4)), rep(3, trunc(L/4)), rep(4, trunc(L/4)), rep(5, trunc(L/4)))
length(Folds)
MYLUBands_RecapAnalysis$Fold<-sample(Folds, replace=F)
#plot(MYLUBands_RecapAnalysis$earlytemp~MYLUBands_RecapAnalysis$Fold)
MYLUBands_RecapAnalysis$Prob<-NA
#Test 1
model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=1,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
summary(model_LOGISTIC)
MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==1] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==1,], type="response", re.form=NA)
#Test 2
model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=2,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
summary(model_LOGISTIC)
MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==2] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==2,], type="response", re.form=NA)
#Test 3
model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=3,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
summary(model_LOGISTIC)
MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==3] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==3,], type="response", re.form=NA)
#Test 4
model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=4,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
summary(model_LOGISTIC)
MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==4] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==4,], type="response", re.form=NA)
#Test 5
model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=5,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
summary(model_LOGISTIC)
MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==5] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==5,], type="response", re.form=NA)

#Plot the ROC curve and get the AUC estimate 
ROC<-roc(response = MYLUBands_RecapAnalysis$EverRecapturedYN.x, predictor = MYLUBands_RecapAnalysis$Prob, plot=TRUE, ci=TRUE, legacy.axes=TRUE)
ROC$auc
#Area under the curve: 0.7353
#95% CI: 0.674-0.7967 (DeLong)
# The AUC can be defined as the probability that the fit model will score a randomly drawn positive sample higher than a randomly drawn negative sample
plot.roc(ROC)
a=ggroc(ROC, size=1, legacy.axes = TRUE) +
  geom_abline(intercept = 0, slope = 1, linetype="dashed") +
  xlab("1-Specificity")+
  ylab("Sensitivity")+
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position = "none", legend.text = element_text(size=20,face="italic"),strip.text = element_text(size=25,face="italic"))
a

#5-fold CV repeated 1000 times
#temp * load
nreps<-1000
L<-length(MYLUBands_RecapAnalysis$YearBand)
Folds<-c(rep(1, (L-4*trunc(L/4))), rep(2, trunc(L/4)), rep(3, trunc(L/4)), rep(4, trunc(L/4)), rep(5, trunc(L/4)))
length(Folds)
MYLUBands_RecapAnalysis$Fold<-sample(Folds, replace=F)
AUC<-rep(NA, nreps)

MYLUBands_RecapAnalysis$Prob<-NA
for(j in 1:length(AUC)) {
  MYLUBands_RecapAnalysis$Fold<-sample(Folds, replace=F)
  #Test 1
  model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=1,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==1] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==1,], type="response", re.form=NA)
  #Test 2
  model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=2,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==2] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==2,], type="response", re.form=NA)
  #Test 3
  model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=3,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==3] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==3,], type="response", re.form=NA)
  #Test 4
  model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=4,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==4] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==4,], type="response", re.form=NA)
  #Test 5
  model_LOGISTIC = glmer(EverRecapturedYN.x~earlytemp*logearlyloads + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=5,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==5] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==5,], type="response", re.form=NA)
  #Get AUC
  AUC[j]<-as.numeric(auc(roc(response = MYLUBands_RecapAnalysis$EverRecapturedYN.x, predictor = MYLUBands_RecapAnalysis$Prob, plot=FALSE, ci=TRUE)))
  print(paste(j, AUC[j], sep=":"))
}
hist(AUC, main = NA)
mean(AUC) #0.7322818 
abline(v=mean(AUC), lty=2)
summary(AUC)
lil<-0.025
big<-0.975
quantile(AUC, c(lil, big))
#2.5%     97.5% 
#0.7142898 0.7449961 

Data<-as.data.frame(AUC); head(Data)
b=ggplot(data=Data, aes(AUC)) +
  geom_histogram(binwidth = 0.005) +
  geom_vline(xintercept = mean(AUC), linetype="dashed") +
  xlab("AUC")+
  ylab("Number of iterations")+
  theme_bw()+
  theme(panel.grid = element_blank(),axis.title=element_text(size=15),
        axis.text=element_text(size=10), axis.line=element_line(),
        legend.position = "none", legend.text = element_text(size=20,face="italic"),strip.text = element_text(size=25,face="italic"))
b
SuppFig<-plot_grid(a, b, labels = c('A', 'B'), rel_widths = c(1,1), label_size = 12); SuppFig
ggsave(file=paste(getwd(), "/SuppFig_AUCs.pdf", sep=""),width=7,height=5.5,units="in",limitsize=FALSE)

#intercept only - for reporting purposes, not for the plot
MYLUBands_RecapAnalysis$Prob<-NA
for(j in 1:length(AUC)) {
  MYLUBands_RecapAnalysis$Fold<-sample(Folds, replace=F)
  #Test 1
  model_LOGISTIC = glmer(EverRecapturedYN.x~1 + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=1,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==1] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==1,], type="response", re.form=NA)
  #Test 2
  model_LOGISTIC = glmer(EverRecapturedYN.x~1 + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=2,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==2] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==2,], type="response", re.form=NA)
  #Test 3
  model_LOGISTIC = glmer(EverRecapturedYN.x~1 + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=3,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==3] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==3,], type="response", re.form=NA)
  #Test 4
  model_LOGISTIC = glmer(EverRecapturedYN.x~1 + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=4,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==4] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==4,], type="response", re.form=NA)
  #Test 5
  model_LOGISTIC = glmer(EverRecapturedYN.x~1 + (1|site.x),family=binomial(),data=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold!=5,], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1000000)))
  MYLUBands_RecapAnalysis$Prob[MYLUBands_RecapAnalysis$Fold==5] = predict(model_LOGISTIC, newdata=MYLUBands_RecapAnalysis[MYLUBands_RecapAnalysis$Fold==5,], type="response", re.form=NA)
  #Get AUC
  AUC[j]<-as.numeric(auc(roc(response = MYLUBands_RecapAnalysis$EverRecapturedYN.x, predictor = MYLUBands_RecapAnalysis$Prob, plot=FALSE, ci=TRUE)))
  print(paste(j, AUC[j], sep=":"))
}
hist(AUC, main = NA)
mean(AUC) #0.7322818 
abline(v=mean(AUC), lty=2)
summary(AUC)
lil<-0.025
big<-0.975
quantile(AUC, c(lil, big))
